@@ -12,7 +12,7 @@ from web.kernel.messaging.channel import GenIMessage
 from web.kernel.proc.isolate import Isolate
 from web.kernel.types import ISocket, RtWriter, \
     GenEventsType, RtResolver, BackTaskTarget, BackTaskTrigger, BackTaskCallback, TaskReturnEvent, \
-    TaskEvent, ITransport, PluginContainer, GenAsyncCall
+    TaskEvent, ITransport, PluginContainer, GenAsyncCall, call_signals, SignalType
 
 
 class Transport(ITransport, metaclass=ABCMeta):
@@ -87,5 +87,6 @@ class TransportIsolate(Isolate):
 
     async def work(self, *args, **kwargs) -> None:
         self._transport.init_plugins()
+        await call_signals(self._transport, SignalType.BEFORE_TRANSPORT_WORK, self._transport)
         loguru.logger.info(f"[{self.name}::Isolate(pid={os.getpid()})]: socket {self._socket}")
         await self._transport.run(self._socket)
