@@ -325,6 +325,7 @@ def cheat(set_to: Any, typed: Type, value: Any, nested: bool = True, self: bool
 
 class SignalType(Enum):
     BEFORE_APP_RUN = "BEFORE_APP_RUN"
+    BEFORE_TRANSPORT_WORK = "BEFORE_TRANSPORT_WORK"
     AFTER_APP_STOP = "AFTER_APP_STOP"
 
 
@@ -634,7 +635,7 @@ class TransportConf(BaseModel):
     socket: SocketConf
 
 
-class ITransport(ConfAble[TransportConf], ChanAble, EnvAble, SharedStateAble, metaclass=ABCMeta):
+class ITransport(ConfAble[TransportConf], ChanAble, EnvAble, SharedStateAble, SigAble, metaclass=ABCMeta):
     services: List[GenService]
     rt_writers: Dict[Type[RtWriter], List[RtWriter]]
     plugins_dir: Path | None
@@ -738,10 +739,9 @@ class Environment(ConfAble, AppNameAble, ChanAble, SharedStateAble):
 
     async def init(self):
         for res in self._resources:
-            loguru.logger.warning(os.getpid())
-            cheat(res, AppNameAble, self.app_name,nested=False)
-            cheat(res, ConfAble, self.conf,nested=False)
-            cheat(res, ChanAble, self.channel,nested=False)
+            cheat(res, AppNameAble, self.app_name, nested=False)
+            cheat(res, ConfAble, self.conf, nested=False)
+            cheat(res, ChanAble, self.channel, nested=False)
             await res.init()
 
     async def shutdown(self):
