@@ -59,12 +59,6 @@ class RestTransport(Transport, AppNameAble, ConfAble[RestTransportConfig]):
         self.sanic.name = self.app_name
         cast(CustomRouter, self.sanic.router).set_routes(self)
 
-        # Todo: it's magick hack to start with asyncio
-        @self.sanic.middleware("request")
-        async def make_cors(request):
-            if request and hasattr(request, "route") and request.route:
-                request.route.ctx._cors = request.app.ctx.cors
-
         start_args = self.conf.sanic.params.dict() if self.conf else {}
         if settings.DEBUG:
             start_args["debug"] = True
@@ -72,4 +66,6 @@ class RestTransport(Transport, AppNameAble, ConfAble[RestTransportConfig]):
                                                 sock=socket,
                                                 return_asyncio_server=True)
         await server.startup()
+        await server.before_start()
+        await server.after_start()
         await server.serve_forever()
